def set_up_python_package(name, tests=True):
    """
    Set up a basic Python package

    Parameters
    ----------
    name : str
        What is the package name?
    tests : bool, optional
        Should tests be included?
    """
    pass

#
# @language('python', help={'name': 'Specify the name of your package',
#                           'tests': 'Should example tests be included?'})
# def set_up_python_package(name, tests=True):
#     pass
