from .registry import service


@service('readthedocs')
def set_up_readthedocs():
    """
    Set up readthedocs for the repository

    Parameters
    ----------
    """
    pass


@service('travis')
def set_up_travis():
    """
    Set up Travis for the repository

    Parameters
    ----------
    """
    pass
